@@ -47,6 +47,11 @@ class DocumentMetaclass(type):
             new_dict = {}
             for key in getattr(self, "_fields"):
                 value = getattr(self, key)
+
+                if type(value) is Field:
+                    key = value.key
+                    value = value.value
+
                 if type(value.__class__) is DocumentMetaclass:
                     new_dict[key] = value.to_dict()
                 else:
@@ -73,7 +78,7 @@ class DocumentMetaclass(type):
             return DocumentMetaclass(
                 f"{self.__class__.__name__}_{other.__class__.__name__}",
                 (object,),
-                { **self_values, **other_values}
+                {**self_values, **other_values}
             )()
 
         def radd(self, other) -> type:
@@ -102,3 +107,13 @@ class FromKeywords(dict):
             setattr(self, key, value)
         self._fields = fields
         dict.__init__(self, **kwargs)
+
+
+class Field:
+    def __init__(self, *, key=None, value=None):
+        if not key:
+            raise TypeError("key must be set and cannot be falsy")
+        if not value:
+            raise TypeError("value must be set and cannot be falsy")
+        self.key = key
+        self.value = value
